package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`"``!````4!T```````!``````````,@'`0``
M````!P``@$``.``*`$``'@`=``8````$````0`````````!``````````$``
M````````,`(````````P`@````````@``````````P````0```!P`@``````
M`'`"````````<`(````````/``````````\``````````0`````````#``!P
M!````(`"````````@`(```````"``@```````!@`````````&``````````(
M``````````$````%````````````````````````````````````]*0`````
M``#TI````````````0```````0````8```#P_P```````/#_`0``````\/\!
M```````H`P```````&`#```````````!```````"````!````'`$````````
M<`0```````!P!````````&`"````````8`(````````(``````````0````$
M````*`0````````H!````````"@$````````1`````````!$``````````0`
M````````4>5T9`<`````````````````````````````````````````````
M````````````$`````````!2Y71D!````/#_````````\/\!``````#P_P$`
M`````!``````````$``````````!````````````````````````````````
M``````````````````````````````````````````@`````````+VQI8C8T
M+VQD+G-O+C$`````0`("`@`!```````````!``````````$H````````]@<`
ML@``````````````````````````,(`"```````!*```````````````````
M`````````````````````#"``@```````2@`````````````````````````
M```````````````P@`(```````$H````````!```L@``````````````````
M````````,(`"```````!*````````#P``;(`````````````````````````
M`#"``@```````2@```````#\'__R```````````````````````````P@`(`
M``````$H````````_/]_LP``````````````````````````,(`"```````!
M*````````(0``+(``````````````````````````#"``@```````2@`````
M```````````````````````````````````P@`(```````$H````````````
ML```````````````````````````,(`"```````$````%`````,```!'3E4`
M;[L@UB?C/=0%(BO>T2]\(N'CBV$$````$`````$```!'3E4```````,````"
M```````````````!`````````"8#`````````0`````````V`P````````$`
M````````0`,````````,`````````&@:````````#0````````!`8P``````
M`!D`````````\/\!```````;``````````@`````````&@````````#X_P$`
M`````!P`````````"``````````$`````````-`&````````!0````````#`
M$P````````8```````````H````````*`````````-$$````````"P``````
M```8`````````#4``'``````X/H!```````5`````````````````````P``
M``````!```(``````!$`````````"!H````````2`````````&``````````
M$P`````````0``````````$``'```````0`````````%``!P``````(`````
M````!@``<`````````````````H``'``````%0`````````1``!P`````&@`
M````````$@``<``````=`````````!,``'``````)``````````>````````
M`!@`````````^___;P`````!```(`````/[__V\`````:!D```````#___]O
M``````(`````````\/__;P````"2&```````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````&$```!H````````
M```````1````+```````````````8@``````````````%@```"\`````````
M)````&8````8`````````#H````C````!````$H````=````"0```&4````_
M``````````````!!````)@```"<```````````````<````E````$```````
M```A````(@```$<```!C````80````````!0`````````%0````@````'```
M`#0`````````10```!,````S````7````#(``````````````!(````V````
M+0```"@```!-````````````````````*@`````````#``````````````!1
M````6``````````Y````0@```#P```````````````````!3````,````!L`
M```?````,0```#<`````````+@```!<````````````````````5````````
M`"D````(````*P```$P```!#````9P``````````````````````````````
M````````````````````````````````"@``````````````5@```%4````.
M``````````````````````````````````````````\````^`````````$``
M```:`````````#T````U```````````````&```````````````>````&0``
M`%D````X`````````$X``````````````%T```!?``````````T````4````
M```````````[`````````%X```!(````9````$8``````````````$\`````
M````1````%H```````````````L```!)````#````````````````@``````
M``!+````8````````````````````%(`````````````````````````!0``
M````````````5P```%L`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````#``T`:!H``````````````````#`$
M```@`!4````"`````````````````-<#```0`!D`(`,"````````````````
M`-T#```2``X`L"@````````8`````````.X#```2``X`@"L```````!4````
M``````$````3`/'_`0```````````````````$@#```2``X`>#\```````#4
M`@```````/L#```2``X``#,```````"4`````````%X#```2``X`J"<`````
M```$`0```````+4#```2``X`V"L````````\`0````````D$```2``X`N%P`
M``````"H`@```````!,$```2``X`$#8```````!(`````````,L#```2``X`
M4$(````````X`0```````-H"```1`!$`<&,````````$`````````"X$```0
M`!4````"`````````````````&8````6`````````````````````````#L$
M```2``X`R%H```````#P`0```````$8$```2``X`4"<```````!4````````
M`$X$```2``X`4!T``````````````````%8$```0`!4````"````````````
M`````%T$```0`!D`(`,"`````````````````/D"```A````````````````
M`````````&D$```0``X`L!H``````````````````'`$```2``X`0%H`````
M``"(`````````'D$```0`!D`4`,"`````````````````!(````1`!8`,``"
M`````````````````/@"```1`````````````````````````*@#```2``X`
MP#<```````"X!P```````'X$```0`!@`&`,"`````````````````(D#```2
M``X`6#8```````!D`0```````'P#```2``X`R"@```````"T`@```````,$#
M```1`!4`(``"```````(`````````'0#```2``X`F#,```````!T````````
M`)L#```2``X`&"T```````#D!0```````-`!```2``X`L!H```````"<`@``
M`````*$!```2````(&,``````````````````,("```2````$&,`````````
M`````````,,!```2`````&,``````````````````*,"```2````\&(`````
M`````````````+<````2````X&(``````````````````,8````2````T&(`
M`````````````````-$````1`````````````````````````!("```2````
MP&(``````````````````.,!```2````L&(``````````````````)4"```2
M````H&(``````````````````$@"```2````D&(``````````````````-X`
M```2````@&(``````````````````/$````2````<&(`````````````````
M`*8!```2````8&(``````````````````"D"```2````4&(`````````````
M`````&D"```2````0&(``````````````````!D"```2````,&(`````````
M`````````+T!```2````(&(```````````````````$"```2````$&(`````
M``````````````8!```2`````&(``````````````````.H````2````\&$`
M`````````````````-4!```2````X&$``````````````````*D````2````
MT&$``````````````````"`"```2````P&$``````````````````/H"```1
M`````````````````````````*H"```2````L&$``````````````````!0#
M```1`````````````````````````!(!```2````H&$`````````````````
M`"4$```2````D&$``````````````````/,!```2````@&$`````````````
M`````+$"```2````<&$``````````````````/H!```2````8&$`````````
M`````````.D"```1`````````````````````````*X!```B````````````
M`````````````+@"```2````4&$``````````````````)H````2````0&$`
M`````````````````"$!```2````,&$``````````````````(D````2````
M`````````````````````'D````2`````````````````````````%@````2
M````(&$``````````````````'D"```2````$&$``````````````````#D"
M```2`````&$``````````````````&H"```2````\&``````````````````
M`#(!```@`````````````````````````(<"```2````X&``````````````
M`````"$````2````T&```````````````````$T````2````P&``````````
M`````````$P!```@`````````````````````````%8"```2````L&``````
M`````````````.L!```2````H&```````````````````&@!```2````D&``
M`````````````````#("```2````@&```````````````````'8!```2````
M<&```````````````````$0````2````8&```````````````````'$"```2
M````4&````````````````````(#```2````0&```````````````````-P!
M```2````,&```````````````````/`"```2````(&``````````````````
M`(8!```B`````````````````````````#$````2````````````````````
M`````%L"```2````$&```````````````````"8````2`````&``````````
M`````````)4!```2````\%\``````````````````)P"```2````X%\`````
M`````````````!P````2````T%\``````````````````($"```2````P%\`
M`````````````````(X"```2````L%\``````````````````,D"```2````
MH%\```````````````````!?1%E.04U)0U],24Y+24Y'`%]?4DQ$7TU!4`!P
M97)L7V9R964`<&5R;%]P87)S90!097)L7V%T9F]R:U]U;FQO8VL`<&5R;%]R
M=6X`<&5R;%]A;&QO8P!097)L7W-Y<U]T97)M`%!,7V-U<G)E;G1?8V]N=&5X
M=`!B;V]T7T1Y;F%,;V%D97(`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T
M<G5C=`!P97)L7V1E<W1R=6-T`%!E<FQ?<WES7VEN:70S`%!E<FQ?;F5W6%,`
M4$Q?9&]?=6YD=6UP`%!E<FQ?<V%F97-Y<VUA;&QO8P!097)L7V-R;V%K7VYO
M8V]N=&5X=`!097)L7VUG7W-E=`!097)L7W-V7W-E='!V;@!097)L7VYE=UA3
M7V9L86=S`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`7TE435]D97)E9VES
M=&5R5$U#;&]N951A8FQE`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V
M`%]?9VUO;E]S=&%R=%]?`%!E<FQ?9V5T7W-V`&5X:70`;65M;6]V90!?7V-X
M85]F:6YA;&EZ90!R;61I<@!?7VQI8F-?<W1A<G1?;6%I;@!S=')S='(`<W1R
M8VAR`'-T<FYC;7``<W1R<F-H<@!U;FQI;FL`;65M8W!Y`%]?<W1A8VM?8VAK
M7V9A:6P`;W!E;C8T`'-T<G1O:P!C;&]S961I<@!R96%D;&EN:P!M96US970`
M7U]V9G!R:6YT9E]C:&L`7U]S<')I;G1F7V-H:P!R96%D`%]?9G!R:6YT9E]C
M:&L`;'-T870V-`!L<V5E:S8T`&]P96YD:7(`;6MD:7(`86-C97-S`&=E='!I
M9`!M96UC:'(`;65M8VUP`'-T<F1U<`!G971U:60`<W1R;&5N`')E861D:7(V
M-`!S=')C;7``7U]E<G)N;U]L;V-A=&EO;@!?24]?<W1D:6Y?=7-E9`!S=&1E
M<G(`<F5A;&QO8P!?7V5N=FER;VX`7U]R96=I<W1E<E]A=&9O<FL`7U]S=&%C
M:U]C:&M?9W5A<F0`;&EB<&5R;"YS;RXU+C,X`&QI8F,N<V\N-@!L9"YS;RXQ
M`%A37TEN=&5R;F%L<U]005)?0D]/5`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`
M<&%R7V1I90!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`<&%R7VEN
M:71?96YV`'!A<E]M:W1M<&1I<@!P87)?9&ER;F%M90!M>5]P87)?<&P`<&%R
M7V-L96%N=7``7V9B<W,`<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S96YA;64`
M<&%R7V5N=E]C;&5A;@!S:&%?9FEN86P`9V5T7W5S97)N86UE7V9R;VU?9V5T
M<'=U:60`7U]D871A7W-T87)T`'-H85]U<&1A=&4`>'-?:6YI=`!?7W-T87)T
M`%]F9&%T80!?7V)S<U]S=&%R=`!?9G1E>'0`<VAA7VEN:70`7V5N9`!?961A
M=&$`1TQ)0D-?,BXT`$=,24)#7S(N,S0`1TQ)0D-?,BXS,P!'3$E"0U\R+C(`
M1TQ)0D-?,BXS+C(`1TQ)0D-?,BXS+C0`1TQ)0D-?,BXP`````````0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``(``0`!``$``0`"
M``$``0`!``$``0`!``$``0`"``(`"0`"``$``0`!``4``@`"``,``0`!``(`
M`@`&``(``@`(``$``@`"``$``@`"``(`!P`!``(``@`"``(``@`%``4``0`!
M``$``0`!``(``P`&``$``@`"``$``0`"``(``0`"``$``0`%``0``@`"``$`
M`0`#``$``0`"``$``@`"``(``````````0`!`$`#```0````(````!1I:0T`
M``<`A00````````!``<`-@,``!``````````M)&6!@``"0"/!```$````!1I
M:0T```@`A00``!````"SD98&```&`)H$```0````$FEI#0``!0"E!```$```
M`'(9:0D```0`KP0``!````!T&6D)```#`+L$```0````$&EI#0```@#'!```
M``````````````````````````#P_P$``````````````!(#^/\!````````
M```````2`R```@``````````````$@,0`P(``````````````!(#"`,"````
M```0````````,/#_O6<``+S_`@`</"W@F0,(`+__R&6<9XB"@M\$`$`0````
M`(B"F=\)^"`#``````@`O]\``+S?"`#@`Q``O6<``````````)#_O6=@`+S_
M`@`</"W@F0.`99QG.`"Q_XB!D=_8@)G?:`"__U@`M?]0`+3_2`"S_T``LO\P
M`+#_)1B`````(MX0`*7_"`"F_Q``I6<(`*9G'`"D9QP`HZ\H`*+_"?@@`P``
M``"0@H;?X(&$WY"`F=\/$1$$)2C``.B`@M\``$*06P!`$"B"F=\H@)#?V(*"
MWSOH`WPM$$,```!#W!P`LH_J!&*0$(&9WP0`1"8#`$(T^"`$``GX(`/J!&*@
M$`"EWR4X0``H@(+?F("#WT`#1_Q`@(+?``"HW$AG0F0<`*:/"`#B_$"`@M\`
M`&3<4&="9`(`PR@#`%(F``#H_!``Y/Q>`&`4&`#B_`,`R"0(`*5D!``$)"4P
M``$``*+<^!@$`"T8XP`!`(0D``!B_/K_AA0(`*5D)1```4"`A=^@@IG?2`,$
MWO@0`@`M$.(`)4```"4P0`+()J5D"?@@`P``0/PQ`$`08(*9WVB!F=](`P3>
M0("2WPGX(`,D`+1G0("$W]`>4F8E*(`"8&2$9"7(0`*C`!$$)9A``"<`0!`H
M@)7?N(*9WPGX(`-(`P3>\(&9WPGX(`,`````*`"CWP``(MXS`&(4:`"_WV``
MO-]8`+7?4`"TWT``LM\X`+'?,`"PWR408`)(`+/?"`#@`W``O6<)^"`#*("0
MWR4@0``A`$`02`,"_M"!F=\)^"`#`````-B"@M\[Z`-\+2!#````@]R;_P`0
MW@E@H`GX(`-(`P3>SO\`$&B!F=\X`Z3>!0"`$*"`F=]6"1$$`````-7_`!"X
M@IG?0("$WR4H@`(ER$`";P`1!.ACA&0E($``S/]`$#@#HO[S_P`0H("9WZ[_
M`!`$``(DN("9WPGX(`,!``0D2(&9WPGX(`,``````````"4`X`,!`!$$````
M`"7(@`,"`!P\U&*<)RW@GP,E^```(("$WP``I=\(`*9G\/\!)"3HH0,E.```
M)4```"5(0``E4*`#R("9WPGX(`,`````__\`$`````````````````(``SPM
M&'D`@&)C9"B`9-PP@&+<.`"$9`4`1!`P@GG<`P`@$P`````(`"`#``````@`
MX`,``````@`#/"T8>0!(8F-D*(!DW#"`9=PX`(1D+RBD`/L0!0#^+P4`+2BB
M`'LH!0`%`*`0$()YW`,`(!,`````"``@`P`````(`.`#``````````#@_[UG
M$`"\_P(`'#PMX)D#^&&<9P@`L/\H@)#?&`"__R`#`I(,`$`4P(&"WP0`0!`X
M@(+?P(&9WPGX(`,``$3<0("9W[`=.6?+_Q$$``````$``B0@`P*B&`"_WQ``
MO-\(`+#?"`#@`R``O6<``````@`"/"T060"(84)D0(!9W.@=.6?*_P`0````
M`````````````````+#_O6=``+S_`@`</"W@F0-(`+__.`"V_S``M?\H`+3_
M(`"S_Q@`LO\0`+'_"`"P_T$`@!!@89QG>(&"WP``5MP]`,`2):"`````@H`E
MF*``)9"``$4`0!`]``,D!`!#$``````!`$*"_/]`%`$`4F8OD%0"`)`2````
MT-X/```2)8C``CT`%23X@)G?)3!``B4H@`()^"`#)2```@0`0!0M&!("``!B
M@!$`51``````"``PWO3_`!8(`#%F2`"_WT``O-\X`+;?,`"UWR@`M-\@`+/?
M&`"RWQ``L=\E$``""`"PWP@`X`-0`+UG`````"^(-@+[B!$```!QKD@`O]\!
M`%)F+8`2`D``O-\X`+;?,`"UWR@`M-\@`+/?&`"RWQ``L=\E$``""`"PWP@`
MX`-0`+UG`````$@`O]\E@```0`"\WS@`MM\P`+7?*`"TWR``L]\8`++?$`"Q
MWR40``((`+#?"`#@`U``O6?"_P`0)9``````````_[UG\`"\_P(`'#PMX)D#
MZ%^<9^``L/^(@9#?Z`"Q_S"!F=_X`+__```"WB4HH`,EB(``V`"B_PGX(`,`
M````#0!`%"``HX\`0`0D`/!C,`,`9!``H`0T"`!D%``````8@IG?`@`%)`GX
M(`,E("`"`@``$`$`0BPE$```V`"DWP```]X&`(,4^`"_W_``O-_H`+'?X`"P
MWP@`X`,``;UG2(&9WPGX(`,``````````.#^O6<0`;S_`@`</"W@F0,X7YQG
M^`"R_XB!DM\8`;__"`&T_P`!L__P`+'_Z`"P_P``0M[8`*+_!`"`$```````
M`(*`#@!`%"6`@`#8`*/?``!"WF,`8A08`;_?$`&\WP@!M-\``;/?^`"RW_``
ML=_H`+#?"`#@`R`!O6<`````^(&9WPGX(`,`````[_]`$"6(0`#(@9G?"?@@
M`R4@(`(Y`$`0<(&9WQ,`0Y#2_V,D!0!@%!,`4V0!`&.2]O]@$,B!F=\`````
M$P!#D-+_8R0U`&`0J(&9WPGX(`,E(``"J(&9WR4@8`()^"`#):!```"@%```
M$`(`(:""`EB!F=\)^"`#`@"$)D"`A]\(@9G?)4A@`B5```)X8^=D__\&)`$`
M!20E($``"?@@`R6@0``(@IG?)2B@`PGX(`,E((`"__\#)`4`8A`@`**/`$`#
M)`#P0C`>`$,00("9WZ"!F=\)^"`#)2"``B""F=\)^"`#)2"``LB!F=\)^"`#
M)2`@`LG_0!1P@9G?"?@@`R4@(`)`@9G?"?@@`R4@``*K_P`0```````````!
M`&.2TO]C),G_8!0``````@!CDK7_8!``````Q/\`$```````````^"`Y9XK_
M$00E((`"X_\`$"""F=](@9G?"?@@`P````"@_[UG4`"\_P(`'#PMX)D#2%V<
M9R``LO^(@9+?&`"Q_Q``L/]8`+__2`"W_T``MO\X`+7_,`"T_R@`L_\E@*``
M```#@@``1=X]``(D)8B```@`I?\"`&(4J(&9WP$`$&8)^"`#)2```D"`F=\$
M`*5G)2`@`M`>.6?;_A$$)9A``%4`0!`EH$``J(&9WPGX(`,E($``*Q!3`$$`
M0!`$`+:/>(&5W_BP%@```"*")1@@`@8`0!0]``0D<P``$"48```!`&*``P!`
M$`$`8V3\_T04`````"\8<0``&`,`6(&9WP(`9&8M((,`"?@@`P``L]XMF'8"
M&P!`$```8OX``*/>```B@BT8=@```&7<`0`D9@``HJ`(`$`4/0`&)`D``!`E
M&*``````````@H`!`(1D)P!`$`$`8J`E&*``^O]&%`$`I60]``0D`0!B9```
M9*````."`0!"9`$`$&;\_V`4__]#H`@`H]\``$+>2P!B%%@`O]]0`+S?2`"W
MWT``MM\X`+7?,`"TWR@`L]\@`++?&`"QWQ``L-\(`.`#8`"]9P```H(!`)1F
M`0`09NW_0!#__X*B```"@@$`E&8!`!!F]_]`%/__@J+F_P`0`````-S_`!`E
M&*``>(&5WP``M]X``.+>*@!`$"40X`(EH```"`!#W"4@@`((`$)D_/]@%`$`
ME"8#`(0D^"`$`"B`@M\P`T.,%`!@%(""F=]8@9G?`0`#)`GX(`,P`T.LS?]`
M$"4@0``@@9G?^+`4`"4PP`()^"`#)2C@`B4@0````*+^`0"")O@0`@`M(((`
M``"`_)'_`!`$`+2O)2B```GX(`,E(.`")2!``+K_0!```*+^\_\`$/BP%`"5
M_P`06(&9WQ``!"3=_P`0):```$B!F=\)^"`#`````+#OO6=`$+S_`@`</"W@
MF0.@6IQG,!"S_Q@0L/^(@9/?)8"``$"`A-\X$+3_(!"Q_RB!F=]($+__*!"R
M_P@`M&<``&+>)8B@`/\/!B0E*(`"@&.$9`@0HO\)^"`#```````0`@`*`$`8
M`````"600`#__T(D$!!#9"T8?0#X[V.`&0!@%/__1"85`$`4`````-B"@M\[
MZ`-\+1!#`$B"F=\``$3<)3`@`@GX(`,E*``""!"CWP``8MX<`&(42!"_WT`0
MO-\X$+3?,!"SWR@0LM\@$+'?&!"PWP@`X`-0$+UG)9"`````````@9G?)3!`
M`B\`!20)^"`#)2"``N3_0!#8@H+?.^@#?"T00P"0@9G?``!$W"4X0`(E,(`"
M"?@@`R4H``+B_P`0`````$B!F=\)^"`#`````.#_O6<0`+S_`@`</"W@F0-H
M69QG"`"P_]B"D-\[Z`-\&`"__RV``P)(@(??0("%W^"`F=_H@8;?```$WMBD
MYV0)^"`#D&.E9$"`B-]`@(7?4("&W]B!F=\```3>0&<(925(```E.``!"?@@
M`[!CI608`+_?$`"\WP@`L-\(`.`#(`"]9P````#P_[UG``"\_P(`'#PMX)D#
MX%B<9]B"@M\[Z`-\"`"__TB`A]]`@(7?+1!#`."`F=_H@8;?``!$W-BDYV0)
M^"`#D&.E9`@`O]\``+S?"`#@`Q``O6<`````L-^]9T`@O/\"`!P\+>"9`XA8
MG&<P(++_B(&2WT@@O__(@IG?.""S_R`@L/\H(+'_``!"W@@`L&<8(*+_"?@@
M`Q`0LV=`@(G?0("'WPB!F=\E(``"R&,I925`0`#08^=D`1`&)`GX(`,!``4D
M*(&9WR4@``(`$`8D"?@@`R4H8`(`@`(`&@``!EB!F=\!``0F"?@@`R6(``((
M`$`0)2!``+"!F=\E,``""?@@`R4H8`(MB%$`)2!`````(*(8(*/?``!"W@P`
M8A1((+_?0""\WS@@L]\P(++?*""QWR`@L-\E$(``"`#@`U`@O6<`````\O\`
M$"4@``!(@9G?"?@@`P```````````@`#/"T8>0"`5V-D6(!YW+G_`!``````
ML.Z]9S@1O/\"`!P\+>"9`VA7G&<H$;;_`!&Q_XB!EM\EB(``0("9WT"`A-](
M$;__"!&R__@0L/]`$;[_,!&W_R`1M?\8$;3_$!&S_P``P][H8X1DT!XY9R60
MH``,`*5GZ!"C_VC]$00`````>(*9WR\`!20E("`""?@@`R6`0``9`$`0T("9
MWT"`A-]`@)G?)2@@`N@B.6=A_A$$^&.$9"40(`+H$*3?``##WGX`@Q1($;_?
M0!&^WS@1O-\P$;??*!&VWR`1M=\8$;3?$!&SWP@1LM\`$;'?^!"PWP@`X`-0
M$;UG`````"4@0`()^"`#0("2WSB!F=\(9$5F"?@@`R4@0`#@_T`0);A``$"`
ME=]`@)3?``#B@N@`LV<09+5F00!`$!ADE&8&```2P("9WR4HX`()^"`#)2``
M`C(`0!`X@9G?J(&9WPGX(`,E(.`"__]#9"T8XP(E\$``*Q#C`@<`0!0O``0D
M#```$*B!F=\``&"@__]C9`0`XQ(```````!B@/K_1!"H@9G?"?@@`R4@X`(E
M\$``J(&9WPGX(`,E("`"+1!>``$`0F0`$$(LM?]`$`B!F=\E4"`")4B@`B5`
MX`(E.(`"`!`&)`$`!20)^"`#)2!@`@B"F=\0`*5G"?@@`R4@8`('`$`4.(&9
MWS``HH\`@`,T`/!",!H`0Q`8@IG?.(&9WPAD168)^"`#)2```)S_0!`EN$``
M``#B@L'_0!0`````!0``$@````````*2TO]")`4`0!``````0("7WP$`'B33
M_P`0X&/W9@$``I+L_T`0.(&9W_G_`!!`@)??``````$`!20)^"`#)2!@`N3_
M0!0X@9G?0("$WT"`F=\E*&`"Z"(Y9^3]$03X8X1DT("9WPGX(`,E(&`"@/\`
M$`````!(@9G?"?@@`P``````````X/^]9Q``O/\"`!P\+>"9`[!4G&=`@IG?
M+P`%)`@`L/\8`+__"?@@`R6`@``"`$`0T("9WP$`4&0)^"`#)2```A@`O]\0
M`+S?"`"PWP@`X`,@`+UG`````,#OO6<P$+S_`@`</"W@F0-85)QG*!"S_XB!
MD]\X$+__(!"R_Q@0L?\0$+#_``!BW@@0HO\T`(`0````````@H`Q`$`0)9"`
M`*B!F=\)^"`#``````$`1F0E@$```1#"+#$`0!"P@9G?"`"Q9R4@(`()^"`#
M)2A``O__`F8M$"("*Q@B`@@`8!0O``0D"0``$$""F=\```````!`H/__0F0%
M`%$0+P`%)```0X#Z_V000(*9WR\`!20)^"`#)2`@`A$`0!`K&"("%0!@%```
M``#0@)G?"?@@`R4@(`(($*3?``!CWA(`@Q0X$+_?,!"\WR@0L]\@$++?&!"Q
MWQ`0L-\(`.`#0!"]9T"`A-_0@)G?"?@@`^!CA&3P_P`0`````.O_`!```$"@
M[/\`$"40``!(@9G?"?@@`P``````````D/^]9U@`O/\"`!P\+>"9`QA3G&=`
M`+7_B(&5WS``L_\H`++_(`"Q_Q@`L/]H`+__8`"^_U``M_](`+;_.`"T_P``
MHMY`@)#?0("2WWB!D]\(`*+_!`"Q9]`>$&8@9%)F)2@@`B7(``)3_!$$)2!`
M`A$`0!`$`*./``!BWO@8`P`M$$,`"`!#W/7_8!```$/\$`!#W`@`0F3]_V`4
M``!#_"4H(`(ER``"0_P1!"4@0`+Q_T`4!`"CCT"`DM]X@9/?,&129B4H(`(E
MR``".OP1!"4@0`(2`$`0!`"CCP``8M[X&`,`+1!#``@`0]SU_V`0``!#_```
M```0`$/<"`!"9/W_8!0``$/\)2@@`B7(``(I_!$$)2!``O#_0!0$`*./0("2
MWWB!D]\X9%)F)2@@`B7(``(@_!$$)2!``A(`0!`$`*./``!BWO@8`P`M$$,`
M"`!#W/7_8!```$/\`````!``0]P(`$)D_?]@%```0_PE*"`")<@``@_\$00E
M($`"\/]`%`0`HX]`@)+?>(&3WTAD4F8E*"`")<@``@;\$00E($`"$P!`$$"`
ME-\$`*./``!BWO@8`P`M$$,`"`!#W/3_8!```$/\$`!#W`@`0F3]_V`4``!#
M_"4H(`(ER``"]?L1!"4@0`+Q_T`4!`"CCT"`E-]X@9/?4&229B4H(`(ER``"
M[/L1!"4@0`(2`$`0!`"CCP``8M[X&`,`+1!#``@`0]SU_V`0``!#_``````0
M`$/<"`!"9/W_8!0``$/\)2@@`B7(``+;^Q$$)2!``O#_0!0$`*./0("2WWB!
MD]]@9%)F)2@@`B7(``+2^Q$$)2!``A,`0!!`@);?!`"CCP``8M[X&`,`+1!#
M``@`0]ST_V`0``!#_!``0]P(`$)D_?]@%```0_PE*"`")<@``L'[$00E($`"
M\?]`%`0`HX]`@);?>(&3W^ACTF8E*"`")<@``KC[$00E($`"$P!`$$"`GM\$
M`*./``!BWO@8`P`M$$,`"`!#W/3_8!```$/\$`!#W`@`0F3]_V`4``!#_"4H
M(`(ER``"I_L1!"4@0`+Q_T`4!`"CCT"`GM]X@9/?<&329R4H(`(ER``"GOL1
M!"4@0`(3`$`00("7WP0`HX\``&+>^!@#`"T00P`(`$/<]/]@$```0_P0`$/<
M"`!"9/W_8!0``$/\)2@@`B7(``*-^Q$$)2!``O'_0!0$`*./0("7WWB!D]^`
M9/)F)2@@`B7(``*$^Q$$)2!``A(`0!`$`*./``!BWO@8`P`M$$,`"`!#W/7_
M8!```$/\`````!``0]P(`$)D_?]@%```0_PE*"`")<@``G/[$00E($`"\/]`
M%`0`HX]`@)+?>(&3WY!D4F8E*"`")<@``FK[$00E($`"$@!`$`0`HX\``&+>
M^!@#`"T00P`(`$/<]?]@$```0_P`````$`!#W`@`0F3]_V`4``!#_"4H(`(E
MR``"6?L1!"4@0`+P_T`4!`"CCT"`DM]X@9/?^&-29B4H(`(ER``"4/L1!"4@
M0`(2`$`0!`"CCP``8M[X&`,`+1!#``@`0]SU_V`0``!#_``````0`$/<"`!"
M9/W_8!0``$/\)2@@`B7(``(_^Q$$)2!``O#_0!0$`*./0("$WR4H(`(ER``"
M./L1!*!DA&0%`$`0)2A``$"`F=_H(CEG./P1!(!DY&9`@(3?)2@@`B7(``(M
M^Q$$N&2$9`8`0!`E*$``0("$WT"`F=_H(CEG+/P1!-!DA&1`@(3?)2@@`B7(
M``(A^Q$$X&2$9!H`0!`E*$``0("9W^@B.6<A_!$$Z&/$9@@`H]\``*+>'P!B
M%$"`A=]`@)G?:`"_WV``OM]8`+S?4`"WWT@`MM]``+7?,`"SWR@`LM\@`+'?
M&`"PWU!DA&8X`+3?"&6E9.@B.6<,_``0<`"]9T"`A-\E*"`")<@``@'[$03P
M9(1DY?]`$"4H0`!`@)G?Z"(Y9P'\$01P9,1GW_\`$`````!(@9G?"?@@`P``
M````````T/^]9R``O/\"`!P\+>"9`S!-G&<8`+#_0("$WXB!D-]`@)G?*`"_
M_P```MX$`*5G<&2$9-`>.6<(`*+_Y/H1!``````.`$`0````````0H`+`$`0
M`````#``0C@K$`(`"`"DWP```]X'`(,4*`"_WR``O-\8`+#?"`#@`S``O6?W
M_P`0)1```$B!F=\)^"`#``````````"@_[UG$`"\_P(`'#PMX)D#F$R<9[B!
M@]\8`+__)6"`````9-R(@8/?`(*9WR@`HF<``&/<*`"E_S``IO\X`*?_)3"`
M`24X0``!``4D0`"H_T@`J?]0`*K_6`"K_P@`H_\)^"`#``"B_[B`F=\)^"`#
M_P`$)``````0@+UGX'^\_P(`'#PMX)D#($R<9\!_LO]@@`,TB(&2W]!_M/_(
M?[/_Z'^__]A_M?^X?['_L'^P_VB"F=\OZ*,#`0`#/`(`!B0``$+>)2@```@`
M8S0M&'T```!B_`GX(`,EH(``__\#)/__4V3\%P,`__]"-"008@($`$$$__\#
M//__0F0E$$,``0!"9"^88@(W`&`&__\")/[_%3P!``(\\/^U-BB`D=\0`$(T
M+1!5`"VH70`0`#%F:(*9WP`````E,```)2A@`@GX(`,E((`"__\#)$,`0Q`X
M@IG?`0`&/`@`QF0E**`""?@@`R4@@`+__P,D`!`"`#8`0Q`E@$``"``"+BP`
M0!3X_Q!F+8"P`BL0%0('`$`0L(*9WR@``!#__P(\`````"L0%0(B`$`4L(*9
MWP@`!B0E*"`""?@@`R4@``+X_T`4__\09@$`$&;^_P(\`0`#//#_0C00`&,T
M+1AB`"T0?0`O$`("+1!3``$``SP(`&,T+1A]````9-P``$/>&P"#%&"`"#0M
MZ*@#Z'^_W^!_O-_8?[7?T'^TW\A_L]_`?[+?N'^QW[!_L-\(`.`#\'^]9___
M`CP`````+9AB`K[_8A9H@IG?Z/\`$/__`B1`@(3?8("9WVK_$00@981D0("$
MWV"`F=]F_Q$$$&6$9$B!F=\)^"`#`````/#_O6<``+S_`@`</"W@F0,@2IQG
M@(&9WP@`O_\)^"`#`````)B!F=\)^"`#)2!```(`0!`(`+_?``!"W```O-\(
M`.`#$`"]9[#_O6=``+S_`@`</"W@F0/829QG,`"S_R@`LO]`@)/?B(&2WT"`
MF=\@`+'_2`"__S@`M/\8`+#_``!"WB6(@``$`*5G,&5D9M`>.6<(`*+_"?H1
M!``````5`$`0)8!`````0H`2`$`08(&9WR4H(`()^"`#)2```AT`0!"H@9G?
M"`"CWP``0MXS`&(42`"_WT``O-\X`+3?,`"SWR@`LM\@`+'?&`"PWP@`X`-0
M`+UG"`"CWP``0MXG`&(4)2@@`D"`F=](`+_?0`"\WS@`M-\H`++?(`"QWQ@`
ML-\P961F,`"SW^@B.6?I^@`04`"]9PGX(`,E("`"J(&9WR4@``()^"`#):!`
M`%B!F=\M(((""?@@`P(`A&1`@(G?0("'WPB!F=\!``4D)5```@AD*64E0"`"
M&&3G9/__!B0E($``"?@@`R6@0``(`*/?``!"WMO_8A`E*(`"2(&9WPGX(`,`
M``````````#^O6?H`;S_`@`</"W@F0-P2)QG0(""W_`!OO^(@9[?X`&W_]`!
MM?_``;/_^`&__]@!MO_(`;3_N`&R_[`!L?^H`;#_)1A``!``HO\``,+?0("3
MWY@!HO]`@(+?)`"U9TAE0F0H`*+_0(""W]`><V;@8T)D,`"B_T"`@M\EN(``
M4&5"9&``HO]`@(+?)2B@`EAE0F1H`*+_0(""W^AC9&1@94)D<`"B_T"`@M\E
MR&`":&5"9'@`HO]`@(+?.`"@_W!E0F1``*+_0(""WX``H/]X94)D2`"B_XWY
M$010`*#_!0!`$("!F=\E@$````!"@%$!0!0`````"?@@`P````"8@9G?"?@@
M`R4@0`"B`$`0````````4=R?`"`2`````*B!F=\)^"`#)2`@`EB!F=]X(`(`
M"?@@`P$`A&0``"B")9!```\``!$E@$``0("4WXAEE&8`````"(&9W_\`"#$E
M($`")3B``O__!B0!``4D"?@@`P$`,68``"B"]O\`%0(`4F9`@(3?0("2WU@`
MM&?09(1D!0``$$@@4F8`````"`"$WA(`@!`(`)1F)<A@`E?Y$00E**`"^?]`
M$"6(0````$*`]O]`$"7(0`*N^1$$)2`@`O+_0!#0@)G?"?@@`R4@(`(2`$`4
M);!```````!`@)+?*`"Q9T@@4F8``#;>#0#`$JB!F=\``,*"8`!`$"7(0`*<
M^1$$)2#``E0`0!30@)G?"``VWO?_P!8(`#%FJ(&9WP`````E(,`""?@@`T"`
ME-^H@9G?)2```@GX(`,EB$```(@1```0`@`AB"("6(&9WP0$)"8)^"`#)8B`
M`$"`BM]`@(??"(&9WR58``*094IE$&2)9B5`P`*89>=D__\&)`$`!20E($``
M"?@@`R600`#`@IG?P`$%)`GX(`,E($`"__\#)`<`8A30@IG?"?@@`P`````1
M``,D``!)C,X`(Q6X@8+?,(&9WX@`I6<)^"`#)2!``@8`0!0E@$``J`"BCP!`
M`R0`\$(P1`!#$("!F=^X@8+?0("&WYB"F=\``.?>``!$W"5`0`+H9<9D"?@@
M`P$`!20EB```F`&CWP``PM\9`6(4^`&_W_`!OM_H`;S?X`&WW]@!MM_0`;7?
MR`&TW\`!L]^X`;+?J`&PWR40(`*P`;'?"`#@`P`"O6<E(,`""?@@`P@`,6:?
M_T`0);!``*S_`!"H@9G?`````*?_`!`EL```0`"DWPT`@!!``+!G)<A@`MGX
M$00E**`"!`!`$"4@0````$*`#@!`%-"`F=\(`!!F```$WO;_@!0ER&`"6(&9
MWPT`!"0)^"`#0("1WT!E,68ED$``)8!``%;_`!!3``@D"?@@`P````!'_T`4
M)8A``.__`!`(`!!F"?@@`[@`MH\`$`(`NO_"%KB!@M^H`**/P`$#)/\!0C"U
M_T,4N(&"WUB!F=\)^"`#)2`@`D"`A-\E**`"0&:$9"7(8`*N^!$$)8A``'X`
M0!`E*$``:("9WR?[$00``.3>>0!`$"6P0`"H@9G?"?@@`R4@P`(`$`(`!`!$
M*!(`@!0E&$``0("%W\"`F=_\_V1D2&:E9"T@Q`()^"`#&`"C_PD`0!08`*/?
M!``")*@`8A#[_V(D+1#"`@``0X`O``(DHP!B$`````!`@)??)2B@`B7(8`**
M^!$$<&3D9EP`0!#P@)G?``!"@%D`0!`P``,D60!#$"4H``!`@(+?0("%WW!D
MY&;H(EED"&6E9(+Y$008`+G_R(*9WT"`D]\)^"`#0("5WT"`A]\(@9G?0&=K
M9B500``09(EF)4!``GAFYV3__P8D`0`%)"4@(`()^"`#__\6)!$`%R1`9W-F
M%```$(AFM68`````"?@@`P```````$*,%`!7%,B"F=\)^"`#`0`0)@B!F=__
M_P8D)5@``B500``09(EF)4!``B4XH`(!``4D)2`@`@GX(`,``+/_P(*9W\`!
M!20)^"`#)2`@`NG_PA+0@IG?((*9WPGX(`,E($`"$`"BWQ@`N=_H8T1D"?@@
M`R4H(`)P@)G?)OX1!"4@(`))_P`0`````$"`AM^8@IG?``#GW@``1-PE0$`"
MJ&7&9`GX(`,!``4D/_\`$"6(````````<("9WQ;^$00E(``"T("9WPGX(`,E
M(``"-O\`$"6(0`"'_P`0``#VWB4H````````"?@@`R4@P`*E_T`0)9A``$"`
MF=\0-#EG<_T1!"4@0`"?_T`$):A``&B"F=\E,```]O]%9"4@8`()^"`#8`&V
M9SB"F=\&``8D)2C``@GX(`,E(&`"!@`#)#D`0Q1!0P(\8`&CCP!#0B2._V(4
M0(""WP0`PY9(10(DBO]B%$"`@M]H@IG?)3```,[_I68E(&`""?@@`V@!L&<X
M@IG?*``&)"4H``()^"`#)2!@`B@``R0C`$,40("+WT"`A]\(@9G?0&=K9250
M``(09(EF)4!``FAFYV3__P8D`0`%)"4@(`()^"`#D`&@HT"`@M_H(D)DG_\`
M$!@`HO\(`/?>7/_@$JB!F=\)^"`#)2#@`@0`0RQ7_V`40("%W\"`F=_\_T)D
M4&:E9`GX(`,M(.("4/\`$`JPX@)(@9G?"?@@`P````!`@(3?8("9WPG]$018
M9H1DL/^]9T``O/\"`!P\+>"9`[A`G&<0`+#_V(*0WSOH`WPP`+3_(`"R_Q@`
ML?](`+__.`"U_R@`L_\M$`,"``!3W$"`D=^(@9+?0("$W[``8Y($`+1GT!XQ
M9@``0MXE*(`"4&2$9"7((`*Q`&.B"`"B_[GW$00`````!`!`$#$``R0``$2`
M?`"#$`````!X@)G?0_L1!``````[Z`-\+1`#`@``4]Q`@(7?6(*9WR4@8`(#
M``<D`0`&)`GX(`.@9J5D$`!`$"680``0`$+<.^@#?"VH`P)`@(;?``!%W$B"
MF=\``*3>"?@@`ZAFQF00`&+>``!%W`P`HHR`!4)\;@!`%%"!F=\[Z`-\+:@#
M`D"`A=]8@IG?``"DW@,`!R0!``8D"?@@`[!FI60-`$`0)9A``$"`A-\E*(`"
M)<@@`H;W$03X8X1D)3!``%$`P!`0`&+>2(*9WP``I-X)^"`#``!%W#OH`WPM
M@`,"```3WD"`A=^H@IG?`0`&)+AFI60)^"`#)2!@`D"`AM](@IG?)2A``-!F
MQF0)^"`#)2!@`D"`A-\```+>)<@@`B4H@`+H8X1DL0!`H&CW$00H@)'?)8!`
M`"$`0!`X`R+^P(*9W\`!!20)^"`#)2```@$`0R0"`&,L"P!@%!$``R0)`$,0
M*("#WT"`A-]``V/<&(&9WP``9=PE.$``)3```@GX(`,`9X1D"`"CWP``0MXK
M`&(42`"_WT``O-\X`+7?,`"TWR@`L]\@`++?&`"QWQ``L-\(`.`#4`"]9P``
M```H@(+?@("9WWW]$01``T3<)8!``-K_0!0X`R+^0("$WQB!F=\)^"`#V&:$
M9``````!`$*`B?]`$'B`F=^"_P`0```````````H@(/?0("9WT`#8]P``$3<
MD"4Y9]SX$00``&7<K/\`$```````````"?@@`P``I-Z0_P`0`````$B!F=\)
M^"`#``````````#`_[UG,`"\_P(`'#PMX)D#X#V<9R``L?\8`+#_0("9WXB!
MD-\EB(``0("$WS@`O_\H`++_```"W@0`I6=P9(1DT!XY9P@`HO\-]Q$$````
M``L`0!````````!"@`@`0!`P``,D!@!#$``````$`"`2````````(H(+`$`4
MB("9WP@`H]\```+>*`!B%#@`O]\P`+S?*`"RWR``L=\8`+#?"`#@`T``O6<W
M^A$$)2`@`D""F=\O``4D)2!```GX(`,ED$```@!`$-"`F=\!`%)D"?@@`R4@
M0`)`@(7?^("9WP0`!B209:5D"?@@`R4@0`#C_T`4``````@`H]\```+>"@!B
M%$"`F=\X`+_?,`"\WR@`LM\8`+#?)2`@`B``L=_X(#EG8/<`$$``O6=(@9G?
M"?@@`P```````````````$#]O6>P`KS_`@`</"W@F0.@/)QGB(&8W[@"O_^H
M`K+_H`*Q_Y@"L/\```+?"`"E9X@"HO\X`(AD>`",9"5(H`#_``L\````````
M!]T```.-/C`'`#X2!P`X5@8`/CX'``#_0C`E$$<`H!@#?`/X1WTX,@8``APC
M`"401P`D,,L``_AC?"401@`(``AE```C_0@`(OWL_X@5$``I97``K=]X`*S?
M@`"CWQ@`J]\@`*K?*`"IWS``J-\X`*??0`"OWP(``!```KED)7C``$``IMP`
M`*+<)7!@`"80P@`F$$T`)A!+`'@8`@#Z%P(`)1AB``/X8WR``*/\"`"E9"5H
M@`$E6$`!)6#``250(`$E2``!)4#@`.S_N10E..`!``"*W!``AMP8`(?<"`"(
MW`@`K=^"6@L\F7EK92``B=SZ'@H`>!$*`"400P`M:*L!)AC'`+I@"`"X+P@`
M)2BL`"UHJ0$#^$)\)!AH``/XK'PF&&<`+1!-`!``K=\M$$,`)AC,``/X0GPD
M&&H`+6BK`2UHIP%X>0(`^LX"`"889@"Z@`H`N'<*`"T8;0`E:/D!)7#0`2T8
M;0`8`*W?)BBN``/X8WPD**(`+6BK`28HK``M:*8!>,D#`/J&`P"X?P(`NA`"
M`"5XX@$M$*T`)2@P`R``K=\M$$4`)BC/`0/X0GP#^,Y]+6BK`20HHP`M8*P!
M>,D"`/J&`@`F**X`N&\#`+H8`P`E:*,!+2BL`"48,`,H`*S?+2BC`"88[0$#
M^*5\`_CO?2088@`M8(L!+6".`7C)!0#ZA@4`)AAO`+AW`@"Z$`(`)7#"`2T8
M;``E$#`#+1AB``/X;'PP`*/?)A"N`20010`#^*U]+1AK`"T8;P!XR0P`^H8,
M`"8030`M$$,`)1@P`RT00P"X?P4`NB@%`"5XY0$#^$5\.`"BWR88SP$D&&P`
M`_C.?2T02P`M$$T`>,D%`/J&!0`F&&X`+1AB`"40,`,M&&(`N&\,`+I@#``E
M:*P!`_AL?$``H]\F$.T!)!!%``/X[WTM&&L`+1AN`'C)#`#ZA@P`)A!/`"T0
M0P`E&#`#+1!#`+AW!0"Z*`4`)7#%`0/X17Q(`*+?)ABN`208;``#^*U]+1!+
M`"T03P!XR04`^H8%`"88;0`M&&(`)1`P`RT88@"X?PP`NF`,`"5X[`$#^&Q\
M4`"CWR80SP$D$$4``_C.?2T8:P`M&&T`>,D,`/J&#``F$$X`+1!#`"48,`,M
M$$,`N&\%`+HH!0`E:*4!`_A%?%@`HM\F&.T!)!AL``/X[WTM$$L`+1!.`'C)
M!0#ZA@4`)AAO`"T88@`E$#`#+1AB`+AW#`"Z8`P`)7#,`0/X;'Q@`*/?)A"N
M`20010`#^*U]+1AK`"T8;P!XR0P`^H8,`"8030`M$$,`)1@P`RT00P"X?P4`
MNB@%`"5XY0$#^$5\:`"BWR88SP$D&&P``_C.?2T02P`M$$T`>,D%`/J&!0`F
M&&X`+1AB`"40,`,M&&(`N&\,`+I@#``E:*P!`_AL?'``H]\F$.T!)!!%``/X
M[WTM&&L`+1AN`'C)#`#ZA@P`)A!/`"T00P`E&#`#+1!#`+AW!0"Z*`4`)7#%
M`0/X17QX`*+?)ABN`208;``#^*U]+1!+`"T03P!XR04`^H8%`"88;0`M&&(`
M)1`P`RT88@"X?PP`NF`,`"5X[`$#^&Q\@`"CWR80SP$D$$4``_C.?2T8:P`M
M&&T`>,D,`/J&#``F$$X`+1!#`"48,`,M$$,`N&\%`+HH!0`E:*4!`_A%?(@`
MHM\F&.T!)!AL``/X[WTM$$L`+1!.`'C)!0#ZA@4`)AAO`+AW#`"Z8`P`)7#,
M`2T88@"0`*S?)1`P`RT88@`F$*X!`_AC?`/XK7TD$$4`+6"+`2U@CP'ZS@,`
M)A!-`'AY`P`E>/D!+1!,`+AG!0"Z*`4`)6"%`9@`N=\M$$\``_A"?"8HS`$M
MR"L#^H8"``/XSGTD**,`>'D"`"UH+0,F**X`)7CP`2THK0`#^.]]N&\#`+H8
M`P`E:*,!+2BO`*``K]\#^+E\)AB-`2UXZP$#^(Q]^H89`"088@!X61D`+7#N
M`288;``E6'`!+1AN``/X:WVX=P(`NA`"`"UX:P`E<,(!J`"KW]EN`SRAZV,T
M`_CP?280K@'ZCA``)A!%`"U88P%X*1``+5AL`24HL0`#^$)\+1!+``/XI7RX
M9QD`NL@9`"5@F0$M6$4`L`"BWP/X>7TF*,P!`_BQ?2T00P`F:*\`^GX9`'@I
M&0`M$%$``_BM?24HKP`M$$T``_BE?+AO$`"Z@!``)6BP`2TH10"X`*+?`_BO
M?":`C0$#^-%]+1!#`"9P"P+ZA@\`>%D/`"T040`#^,Y])5AP`2T03@`#^&M]
MN'<9`+K(&0`E<-D!+5A+`,``HM\#^'E])H"N`0/XD7TM$$,`)F`%`OJ&&0!X
M*1D`+1!1``/XC'TE*+``+1!,``/XI7RX9P\`NG@/`"5@CP$M*$4`R`"BWP/X
MKWPF@,P!`_BQ?2T00P`F:`L"^H8/`'A9#P`M$%$``_BM?258<`$M$$T``_AK
M?;AO&0"ZR!D`)6BY`2U82P#0`*+?`_AY?2:`C0$#^-%]+1!#`"9P!0+ZAAD`
M>"D9`"T040`#^,Y])2BP`"T03@`#^*5\N'</`+IX#P`E<,\!+2A%`-@`HM\#
M^*]\)H"N`0/XD7TM$$,`)F`+`OJ&#P!X60\`+1!1``/XC'TE6'`!+1!,``/X
M:WVX9QD`NL@9`"5@F0$M6$L`X`"BWP/X>7TF@,P!`_BQ?2T00P`F:`4"^H89
M`'@I&0`M$%$``_BM?24HL``M$$T``_BE?+AO#P"Z>`\`)6BO`2TH10#H`*+?
M`_BO?":`C0$#^-%]+1!#`"9P"P+ZA@\`>%D/`"T040`#^,Y])5AP`2T03@`#
M^&M]N'<9`+K(&0`E<-D!+5A+`/``HM\#^'E])H"N`0/XD7TM$$,`)F`%`OJ&
M&0!X*1D`+1!1``/XC'TE*+``+1!,``/XI7RX9P\`NG@/`"5@CP$M*$4`^`"B
MWP/XKWPF@,P!`_BQ?2T00P`F:`L"^H8/`'A9#P`M$%$``_BM?258<`$M$$T`
M`_AK?;AO&0"ZR!D`)6BY`2U82P```:+?`_AY?2:`C0$#^-%]+1!#`"9P!0+Z
MAAD`>"D9`"T040`#^,Y])2BP`"T03@`#^*5\N'</`+IX#P`E<,\!+2A%``@!
MHM\#^*]\)H"N`0/XD7TM$$,`)F`+`OJ&#P!X60\`+1!1``/XC'TE6'`!+1!,
M``/X:WVX9QD`NL@9`"5@F0$M6$L`$`&BWP/X>7TF@,P!`_BQ?2T00P`F:`4"
M^H89`'@I&0`M$%$``_BM?24HL``M$$T``_BE?+AO#P"Z>`\`)6BO`2TH10`8
M`:+?`_BO?":`C0$#^-%]+1!#`"9P"P+ZA@\`>%D/`"T040`#^,Y])5AP`2T0
M3@`#^&M]N'<9`+K(&0`E<-D!+5A+`"`!HM\#^'E])H"N`0/XD7TM$$,`)F`%
M`OJ&&0!X*1D`+1!1``/XC'TE*+``+1!,``/XI7RX9P\`NG@/`"TH10`E8(\!
M*`&BWP/XL'PF>,P!`_BQ?2T00P`F:.L!^GX0`'A9$``M$%$``_BM?258;P$M
M$$T``_AK?;AO&0"ZR!D`)6BY`2U82P`P`:+?`_AO?2;(C0'ZC@\`+1!#``/X
MSGTFR"4#>"D/`"T03@`#^#E_)2BQ`"T060"X=Q```_BE?+J`$``M*$4`)7#0
M`3@!HM\F@*X!`_BY?"T00P`#^(Q])E@+`OJ.&0!X@1D`+1!,``/X:WVX9P\`
M+1!+`+IX#P`E6!$")6"/`2T02P!``:O?)H#,`0/X3WPM6&,!)A`%`@/XK7TM
M6&T!`_A"?/IN#P!X*0\`N!\9`"U88@&ZR!D`QB,"/"48>0`E**T`2`&YWS?O
M0C2X$`(``_AM?"U890$E*(,!`_AK?22`C0$D**\`+<@B`P/XSGTMR"X#^HX+
M`"4HL`"X=P\`>($+`+IX#P`E<,\!+2BY`"5X$0(M**\``_BO?%`!I=\E&&X`
M),C-`2THH@`D&&L``_B,?2U@K`#ZA@\`)1AY`+@O"P!XR0\`NE@+`"4HJP`M
M&&P`)5@P`U@!N=\#^*Q\+1AK`"58Q0$#^&-\)(#,`218;P$MR"(#+<@M`_J.
M`P`E6'`!N&\/`'B!`P"Z>`\`)6BO`2U8>0$E>!$"+5AO`0/X;WU@`:O?)2BM
M`"3(K`$#^,Y])"BC`"U88@$M6&X!N(<#`'AQ#P`E*+D`NA@#`/K.#P`E&`,"
M+2BK`"58V0%H`;G?`_AN?"THJP`E6*,!`_BE?"2`K@$D6&\!+<@B`RW(+`/Z
MC@4`)5AP`;AG#P!X@04`NG@/`"5@CP$M6'D!)7@1`BU8;P$#^&]]<`&KWR48
M;``DR(X!`_BM?20890`M6&(!+5AM`;B'!0!X:0\`)1AY`+HH!0#ZS@\`)2@%
M`BT8:P`E6+D!>`&YWP/XK7PM&&L`)5B%`0/X8WPD@(T!)%AO`2W((@,MR"X#
M^HX#`"58<`&X=P\`>($#`+IX#P`E<,\!+5AY`25X$0(M6&\!`_AO?8`!J]\E
M**X`),C-`0/XC'TD**,`+5AB`2U8;`&XAP,`>&$/`"4HN0"Z&`,`^LX/`"48
M`P(M**L`)5B9`8@!N=\#^&Q\+2BK`"58PP$#^*5\)(#,`218;P$MR"(#+<@M
M`_J.!0`E6'`!N&\/`'B!!0"Z>`\`)6BO`2U8>0$E>!$"+5AO`0/X;WV0`:O?
M)1AM`"3(K`$#^,Y])!AE`"U88@$M6&X!N(<%`'AQ#P`E&'D`NB@%`/K.#P`E
M*`4"+1AK`"58V0&8`;G?`_BN?"T8:P`E6*4!`_AC?"2`K@$D6&\!+<@B`RW(
M+`/ZC@,`)5AP`;AG#P!X@0,`NG@/`"5@CP$M6'D!)7@1`BU8;P$#^&]]H`&K
MWR4HK``DR(X!`_BM?20HHP`M6&(!+5AM`;B'`P!X:0\`)2BY`+H8`P#ZS@\`
M)1@#`BTHJP`E6+D!J`&YWP/X;7PM**L`)5B#`0/XI7PD@(T!)%AO`2W((@,M
MR"X#^HX%`"58<`&X=P\`>($%`+IX#P`E<,\!+5AY`25X$0(M6&\!`_AO?;`!
MJ]\E&&X`),C-`0/XC'TD&&4`+5AB`2U8;`&XAP4`>&$/`"48>0"Z*`4`^LX/
M`"4H!0(M&&L`)5B9`;@!N=\#^*Q\+1AK`"58Q0$#^&-\)(#,`218;P$MR"(#
M+<@M`_J.`P`E6'`!N&\/`'B!`P"Z>`\`)6BO`2U8>0$E>!$"+5AO`0/X>7W`
M`:O?)2BM`"1XK`$#^,Y])"BC`"U88@$M6&X!N(<#`'AQ&0`E**\`NA@#`/I^
M&0`E&`,"+2BK`,@!L-\E6,\!+2BK``/X;GPE6*,!`_BE?"1XK@$D6'D!+8`"
M`BV`#`)XB04`^I8%`+I@&0`E6&\!N'\9`"5X[`$M6'`!)6`R`BU8;`'0`:S?
M)1AO``/X:WTDR.X!`_BM?20890`M8((!+6"-`248>0!X:0L`^LX+`"T8;``E
M8+D!N&\%`+HH!0`E**4!V`&PWRT8;``#^&-\`_BM?"5@Y0$DD.T!+8`"`OJ.
M`P`D8(L!>,D#`"UP#@(E8)(!)<@Q`RU@C@$#^#E_N'<+`+I8"P#@`;#?)7#+
M`2U@F0$#^)E])2BN`"0HHP`DD,T!+8`"`OJ.&0`#^.M]>'D9`"U8"P(E$+(`
M)2CQ`;A_`P"Z&`,`+1!+`"5XXP$#^*5\+2A%`"88SP$Q90(\)AAL`.M@0F3H
M`:S?>!`"``/XL'SZCA``+6""`7A9$``M8(T!)5AQ`0/X8WPM&&P``_AK?;AG
M&0"ZR!D`)6"9`2UH:P#P`:O?`_BY?288[`'ZCAD``_C.?28890`M6&(!>"D9
M`"U8;@$E*+$``_AC?"T8:P`#^*5\N%\0`+J`$``E6'`!+2AE`/@!H]\#^+!\
M)G"+`?J.$``M&&(``_CO?29PS0%X:1``+1AO``/XSGTE:+$!+1AN``/XK7VX
M=QD`NL@9`"5PV0$M>&T```*CWP/X^7TF:&X!`_B1?2T88@`F8*4!^FX9`'@I
M&0`M&'$``_B,?24HK0`M&&P`N&\0``/XI7RZ@!``)6BP`2TH90`(`J/?`_BP
M?"9@S0$#^'%]+1AB`"9@CP%X61``^GX0`"T8<0`#^(Q])5AO`2T8;``#^&M]
MN&<9`+K(&0`E8)D!+5AK`!`"H]\#^&]])LBL`0/XT7TM&&(`)G`E`_K.#P!X
M*0\`+1AQ``/XSGTE*+D`+1AN``/XI7RX=Q``NH`0`"5PT`$M*&4`&`*CWP/X
MN7PF@(X!`_BQ?2T88@`F:`L"^H89`'A9&0`M&'$``_BM?258<`$M&&T``_AK
M?;AO#P"Z>`\`)6BO`2U8:P`@`J/?`_AO?2:`S0$#^)%]+1AB`"9@!0+ZA@\`
M>"D/`"T8<0`#^(Q])2BP`"T8;``#^*5\N&<9`+K(&0`E8)D!+2AE`"@"H]\#
M^+E\)H"L`0/XT7TM&&(`)G`+`OJ&&0!X61D`+1AQ``/XSGTE6'`!+1AN``/X
M:WVX=P\`NG@/`"5PSP$M6&L`,`*CWP/X;WTF@(X!`_BQ?2T88@`F:`4"^H8/
M`'@I#P`M&'$``_BM?24HL``M&&T``_BE?+AO&0"ZR!D`)6BY`2TH90`X`J/?
M`_BY?":`S0$#^)%]+1AB`"9@"P+ZAAD`>%D9`"T8<0`#^(Q])5AP`2T8;``#
M^&M]N&</`+IX#P`E8(\!+5AK`$`"H]\#^&]])H"L`0/XT7TM&&(`)G`%`OJ&
M#P!X*0\`+1AQ``/XSGTE*+``+1AN``/XI7RX=QD`NL@9`"5PV0$M*&4`2`*C
MWP/XN7PF@(X!`_BQ?2T88@`F:`L"^H89`'A9&0`M&'$``_BM?258<`$M&&T`
M`_AK?;AO#P"Z>`\`)6BO`2U8:P!0`J/?`_AO?2:`S0$#^)%]+1AB`"9@!0+Z
MA@\`>"D/`"T8<0`#^(Q])2BP`"T8;``#^*5\N&<9`+K(&0`E8)D!+2AE`%@"
MH]\#^+!\)LBL`0/XT7TM&&(`)G`K`_K.$`!X61``+1AQ``/XSGTE6'D!+1AN
M``/X:WVX=P\`NG@/`"5PSP$M6&L`8`*CWP/X;WTFR(X!`_BQ?2T88@`F:"4#
M^LX/`'@I#P`M&'$``_BM?24HN0`M&&T`N,\0``/XI7RZ@!``)<@P`RTH90!H
M`J/?`_BQ?"9HV0$#^)!]+1AB`"9@JP'Z;A$`>%D1`"T8<``#^(Q])5AM`2T8
M;``#^&M]N&\/`+IX#P`M8&L`)6BO`7`"H]\#^)!])E@M`R9890'Z?A``+1AB
M``/XSGUX*1``+1AN`"4HKP`#^&Y]+1AN`+A?$0`#^*5\NH@1`"58<0$M>&4`
M>`*EWR88JP$#^.Y]+2BB``/X.7\F&&P`+2BY``/X8WQXR0X`^HX.`"THHP`E
M&#$#N&<0`"THHP"Z@!``@`*CWR5@D`$M$&(`)AAL`0/XI7PM$$H``_BM?288
M;P!X404`+1!-``/X8WSZ;@4`+1!#`"4830$M$$,``_A"?+@?#@"Z<`X```""
M_"48;@`M&&8`B`*JWRTPAP$M**@`+1!I`0``!]\#^*5\`_AC?`/XQGP#^$)\
M"`"%_!``@_P8`(;\"`!'%2``@ORX`K_?L`*\WZ@"LM^@`K'?F`*PWP@`X`/`
M`KUG2(&9WPGX(`,``````````/#_O6<``+S_`@`</"W@F0/P)9QG6(&9WP@`
MO_\)^"`#@``$)%U,!3Q_;J5D>"@%`.=W!B0]#`0\$`!%_$5G!SQX-`8`,A`%
M/!\NA&0!(^=DB:O&9'94I60X(00```!'_`@`1OP8`$7\(`!$_"@`0/PP`$#\
M>`!`K`@`O]\``+S?"`#@`Q``O6>P_[UG0`"\_S@`MO\8`++_$`"Q_T@`O_\P
M`+7_*`"T_R``L_\(`+#_*`"#W/@0!@`M$$,``@`</`/X0GPMX)D#*QA#`"6P
MP`!H)9QG,`"&W"60@``"`&`0)8B@``$`QF1Z'Q8`>`!$CBT89@`H`$+^10"`
M%#``0_XX`%!F0`#"*ED`0!1`@)7?P/_6)H/)TWX!`'1FN*$4`"V@-`*00[5F
M!P`I:@\`*&H``"EN%P`G:A\`)FHG`"5J+P`D:C<`(VH_`")J"``H;A``)VX8
M`"9N(``E;B@`)&XP`"-N.``B;@<`";(```FV#P`(L@@`"+87``>R$``'MA\`
M!K(8``:V)P`%LB``!;8O``2R*``$MC<``[(P``.V)2!``C\``K(ER*`".``"
MMN?Y$01``#%FV_\T%@````"`F1,`([#3`K"!F=\E,,`")2B``@GX(`,E(``"
M>`!6KD@`O]]``+S?.`"VWS``M=\H`+3?(`"SWQ@`LM\0`+'?"`"PWP@`X`-0
M`+UG`````$``%20C$*0"*AC"`@L0PP*P@9G?.`!09B4P0``E*"`"+2`$`@GX
M(`,EH$``>`!"CB$05`#F_U44>`!"KD"`E=\E($`"D$.U9B7(H`*\^1$$([#4
M`J?_`!`MB#0"`````-7_`!`EH"`"P/^]9S``O/\H`+7_"`"Q_P``L/\X`+__
M(`"T_Q@`L_\0`++_*`"RW#@`M63#*$-^`0!B9`(`'#PE@*``+>"9`RT8HP(E
MB(``.0!%*(#_!"0P`!/>>".<9W4`H!0``&2@0``#)",88@`$`&0LA`"`$"T0
MH@("`&0L>0"`$`````!U`&`4`````$"`E-^00Y1F)<B``I#Y$00E(``"4(*9
MWS@`!B0E*```"?@@`R4@H`(Z'A,``!@#`#HD$P`E$```!SAB?``@!``Z&A,`
M!WJ"?``8`P`'O&)\`)@3`#H>$@`'_F)^`!@#`#HD$@`&.&)\`"`$`#H:$@``
M&`,`!GJ"?`:\8GP`D!(`!OY"?B4@``(ER(`"</D1!'```OX```+>((*9WSH6
M`@```"*B```"WB4@``(Z%`(``0`BH@```MXZ$@(``@`BH@```MX#`"*B"``"
MWCH6`@`$`"*B"``"WCH4`@`%`"*B"``"WCH2`@`&`"*B"``"W@<`(J(0``+>
M.A8"``@`(J(0``+>.A0"``D`(J(0``+>.A("``H`(J(0``+>"P`BHA@``MXZ
M%@(`#``BHA@``MXZ%`(`#0`BHA@``MXZ$@(`#@`BHA@``MX/`"*B(``"WCH6
M`@`0`"*B(``"WCH4`@`1`"*B(``"WCH2`@`2`"*B(``"W@GX(`,3`"*B.`"_
MWS``O-\H`+7?(`"TWQ@`L]\0`++?"`"QWP``L-\(`.`#0`"]9P````!0@IG?
M.``&)$"`E-\C,,(`)2@``"T@H@()^"`#D$.49IC_`!`Z'A,`B_\`$```0*#^
M_V-D````````0*`!`$"@A?]@$`(`0F2#_P`0``!`H/S_8V0"`&0L``!`H`$`
M0*`"`$"@`P!`H'G_@!0$`$)D\?\`$/[_8V3P_[UG``"\_P(`'#PMX)D#T""<
M9SB`@M]P@IG?``!'W`@`O_\)^"`#``````@`O]\``+S?"`#@`Q``O6<`````
M$("9WR5XX`,)^"`#9P`89!"`F=\E>.`#"?@@`V8`&&00@)G?)7C@`PGX(`-E
M`!AD$("9WR5XX`,)^"`#9``89!"`F=\E>.`#"?@@`V,`&&00@)G?)7C@`PGX
M(`-B`!AD$("9WR5XX`,)^"`#80`89!"`F=\E>.`#"?@@`V``&&00@)G?)7C@
M`PGX(`-=`!AD$("9WR5XX`,)^"`#7``89!"`F=\E>.`#"?@@`UL`&&00@)G?
M)7C@`PGX(`-:`!AD$("9WR5XX`,)^"`#60`89!"`F=\E>.`#"?@@`U@`&&00
M@)G?)7C@`PGX(`-7`!AD$("9WR5XX`,)^"`#5@`89!"`F=\E>.`#"?@@`U4`
M&&00@)G?)7C@`PGX(`-4`!AD$("9WR5XX`,)^"`#4@`89!"`F=\E>.`#"?@@
M`U$`&&00@)G?)7C@`PGX(`-0`!AD$("9WR5XX`,)^"`#3@`89!"`F=\E>.`#
M"?@@`TT`&&00@)G?)7C@`PGX(`-,`!AD$("9WR5XX`,)^"`#2P`89!"`F=\E
M>.`#"?@@`T@`&&00@)G?)7C@`PGX(`-'`!AD$("9WR5XX`,)^"`#1@`89!"`
MF=\E>.`#"?@@`T,`&&00@)G?)7C@`PGX(`-"`!AD$("9WR5XX`,)^"`#00`8
M9!"`F=\E>.`#"?@@`T``&&00@)G?)7C@`PGX(`,_`!AD$("9WR5XX`,)^"`#
M/0`89!"`F=\E>.`#"?@@`SL`&&00@)G?)7C@`PGX(`,Z`!AD$("9WR5XX`,)
M^"`#.0`89!"`F=\E>.`#"?@@`S@`&&00@)G?)7C@`PGX(`,W`!AD$("9WR5X
MX`,)^"`#-@`89!"`F=\E>.`#"?@@`S4`&&00@)G?)7C@`PGX(`,T`!AD$("9
MWR5XX`,)^"`#,P`89!"`F=\E>.`#"?@@`S(`&&00@)G?)7C@`PGX(`,Q`!AD
M$("9WR5XX`,)^"`#,``89!"`F=\E>.`#"?@@`R\`&&00@)G?)7C@`PGX(`,N
M`!AD$("9WR5XX`,)^"`#+0`89!"`F=\E>.`#"?@@`RP`&&00@)G?)7C@`PGX
M(`,K`!AD$("9WR5XX`,)^"`#*0`89!"`F=\E>.`#"?@@`R@`&&00@)G?)7C@
M`PGX(`,G`!AD$("9WR5XX`,)^"`#)@`89!"`F=\E>.`#"?@@`R4`&&00@)G?
M)7C@`PGX(`,D`!AD`````````````````````/#_O6<``+S_`@`</"W@F0,(
M`+__\!R<9P@`O]\``+S?"`#@`Q``O6<```````````$``@``````)7,O)7,`
M```O<')O8R]S96QF+V5X90``1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R
M``````!);G1E<FYA;',Z.E!!4CHZ0D]/5`````!E>&4``````"]P<F]C+R5I
M+R5S```````N`````````%!!4E]414U0``````````!005)?4%)/1TY!344`
M````.@`````````O`````````"5S)7,E<P``4$523#5,24(``````````%!%
M4DQ,24(`4$523#5/4%0``````````%!%4DQ)3P``4$%27TE.251)04Q)6D5$
M`%!!4E]34$%73D5$``````!005)?0TQ%04X`````````4$%27T1%0E5'````
M`````%!!4E]#04-(10````````!005)?1TQ/0D%,7T1%0E5'``````````!0
M05)?1TQ/0D%,7U1-4$1)4@````````!005)?5$U01$E2````````4$%27T=,
M3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X``````````#$`````````;'-E
M96L@9F%I;&5D`````')E860@9F%I;&5D``````!,1%],24)205)97U!!5$@`
M4UE35$5-```O=&UP`````%1-4$1)4@``5$5-4$1)4@!414U0`````%1-4```
M````55-%4@````!54T523D%-10``````````)3`R>`````!P87(M`````"5S
M)7,E<R5S```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R:79A=&4@
M<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A
M;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@```````%!!5$@`````<&%R;```
M```N<&%R`````'-H;W)T(')E860````````E<R5S8V%C:&4M)7,E<P``)7,E
M<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U)7,``````````!@`````````
M<&5R;``````P`````````%!!4CHZ4&%C:V5R.CI615)324].`````#$N,#8R
M````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``````````"5S
M.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F
M86EL960@*&5R<FYO/25I*0H``````````"UE````````+2T```````!E=F%L
M("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@
M(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?
M<&P["FUY("@D4$%27TU!1TE#+"`D1DE,15]O9F9S971?<VEZ92P@)&-A8VAE
M7VYA;65?<VEZ92D["D)%1TE.('L*)%!!4E]-04=)0R`](")<;E!!4BYP;5QN
M(CL*)$9)3$5?;V9F<V5T7W-I>F4@/2`T.R`@(",@<&%C:R@B3B(I"B1C86-H
M95]N86UE7W-I>F4@/2`T,#L*)%!+6DE07TU!1TE#(#T@(E!+7#`P,UPP,#0B
M.PI]"G-U8B!F:6YD7W!A<E]M86=I8PI["FUY("@D9F@I(#T@0%\["FUY("1C
M:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US
M("1F:#L*;7D@)'!O<R`]("@D<VEZ92TQ*2`M("@D<VEZ92TQ*2`E("1C:'5N
M:U]S:7IE.R`@("`@(",@3D]413H@)'!O<R!I<R!A(&UU;'1I<&QE(&]F("1C
M:'5N:U]S:7IE"G=H:6QE("@D<&]S(#X](#`I('L*<V5E:R`D9F@L("1P;W,L
M(#`["G)E860@)&9H+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%2
M7TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#
M*2D@/CT@,"D@>PIR971U<FX@)'!O<R`K("1I.PI]"B1P;W,@+3T@)&-H=6YK
M7W-I>F4["GT*<F5T=7)N("TQ.PI]"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M
M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D14Y6>U!!
M4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z
M.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&
M:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q6U)E
M;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I;F0Z.F9I
M;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R
M7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@
M)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H
M"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M
M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+
M(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE.PIP<FEN
M="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O
M"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[
M('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*
M<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W,#`L("1F
M:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L;"`R/B8Q
M("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K9W)O=6YD
M('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=*3L*?0I]
M('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@
M)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I
M.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES(#T@*`IP
M871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*
M7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI
M+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU3
M5VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PIO
M=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T7W!A<E]T
M96UP*"D["F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%
M35!](ETI.PIM>2`H)'-T87)T7W!O<RP@)'-T87)T7V]F7T9)3$5?<V5C=&EO
M;BD["DU!1TE#.B!["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIU
M;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA;64I('L*;W5T<RAQ
M<5M#86XG="!R96%D(&9R;VT@9FEL92`B)'!R;V=N86UE(ETI.R`@(R!D;VXG
M="!U<V4@)"$@:&5R92!A<R!I="!R97%U:7)E<R!%<G)N;RYP;0IL87-T($U!
M1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@J7T9(*3L*
M:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;0V%N)W0@9FEN9"!M86=I
M8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*
M;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!005(@;6%G:6,@870@<&]S:71I
M;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%
M7V]F9G-E=%]S:7IE("T@;&5N9W1H*")<,$-!0TA%(BDL(#`["G)E860@7T9(
M+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@;F4@(EPP0T%#
M2$4B("8F("1B=68@;F4@(EPP0TQ%04XB*2!["F]U=',H(DYO(&-A8VAE(&UA
M<FME<B!F;W5N9"(I.PIL87-T($U!1TE#.PI]"F]U=',H<7%;0V%C:&4@;6%R
M:V5R("(D8G5F(B!F;W5N9%TI.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&
M24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&2"P@)&)U9BP@)$9)3$5?;V9F
M<V5T7W-I>F4["FUY("1O9F9S970@/2!U;G!A8VLH(DXB+"`D8G5F*3L*;W5T
M<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,17,@:7,@)&]F9G-E="(I.PIS
M965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@)&]F
M9G-E="P@,#L*)'-T87)T7V]F7T9)3$5?<V5C=&EO;B`]('1E;&P@7T9(.PIM
M>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@
M("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL
M92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@
M7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@
M)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI
M.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\
M("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F
M(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T
M.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I
M;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@
M>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P
M-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I
M;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D
M9G5L;&YA;64["GT*96QS92!["B1-;V1U;&5#86-H97LD9G5L;&YA;65](#T@
M>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE
M+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D(%]&2"P@
M)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO
M9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE
M.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T=7)N('5N
M;&5S<R`D:6YF;SL*9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T["B1)
M3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%
M3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B0V%N)W0@
M8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*)&9H+3YP
M<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E='5R;B`D
M9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D:6YF;RT^
M>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5](#T@)&9I
M;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I
M92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B.B`D(5T["G)E='5R;B`D9F@[
M"GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U
M;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q
M=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E
M($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E
M<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@
M*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[
M)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F
M:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]
M"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET
M96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F
M:6QE;F%M97T["GT*:68@*"1B=68@;F4@)%!+6DE07TU!1TE#*2!["F]U=',H
M<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F:6QE("(D
M<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@/2`H=&5L
M;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM
M>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H
M95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I
M>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"FEF("@A)'-T
M87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H
M:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@
M("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*
M=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G
M+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@
M/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO
M=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]
M?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@
M97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E
M<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2![
M"G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2![
M"B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G
M<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<[
M"GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D
M,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92!Q<5M#
M86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H)#$@97$@
M)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H
M;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]4
M14U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z
M.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@
M0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I
M;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!
M.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I
M;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1P87(@;W(@9&EE
M('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L97-S*"1F
M:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D
M>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E
M.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@
M87)C:&EV92`B)'!A<B)=.PI]"FUY("5M971A7W!A<B`](&1O('L*:68@*"1Z
M:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI
M('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO
M+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*:68@
M*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O
M<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@
M)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T
M(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q("102UI)4%]-04=)0SL*8VQO
M<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z
M.D]?4D174B@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D
M:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F:"T^8FEN
M;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@*&1E9FEN
M960@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD@>PIR96%D(%]&2"P@)&QO861E
M<BP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;CL*?2!E;'-E('L*;&]C86P@)"\@
M/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM005)?5D52
M0D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"B1F:"T^<')I;G0H)&QO861E
M<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@;&]A9&5R('1O("(D;W5T(CH@
M)"%=.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ
M2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER
M95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E
M<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O
M;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R
M:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O<F5A8V@@
M0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R
M.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT
M(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@6%A8(&QI
M8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M>2`D:V5Y
M("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I.PII9B`H
M9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1K97E]
M*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L<V4@>PIF
M;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>7%$D9&ER
M7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D,2D["FQA
M<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI)'PI('L*
M:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA
M;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O)#$B*2![
M"B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*
M?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@)'=R:71T
M96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^
M("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A8VMI;F<@
M1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F
M:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N
M="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*
M;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#86XG="!R
M96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)'1H/CL*8VQO<V4@)'1H
M.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@(CQE
M;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D
M;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C
M:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I
M.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H*"1N86UE
M*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP
M=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L96YG=&@H
M)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG
M(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D(5T["F]U=',H<7%;5W)I='1E
M;B!A<R`B)&YA;64B72D["GT*?0II9B`H)'II<"D@>PHD>FEP+3YW<FET951O
M1FEL94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TL*;W(@9&EE
M('%Q6T5R<F]R('=R:71I;F<@>FEP('!A<G0@;V8@(B1O=70B73L*?0II9B`H
M)&UE=&%?<&%R>V-L96%N?2D@>PHD9F@M/G!R:6YT*")<,$-,14%.(BD["GT*
M96QS92!["FEF("@A9&5F:6YE9"`D8V%C:&5?;F%M92D@>PIM>2`D8W1X(#T@
M1&EG97-T.CI32$$M/FYE=R@Q*3L*<V5E:R`D9F@L(#`L(#`["B1C='@M/F%D
M9&9I;&4H)&9H*3L*<V5E:R`D9F@L(#`L(#(["B1C86-H95]N86UE(#T@)&-T
M>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N
M86UE+"`P+"`D8V%C:&5?;F%M95]S:7IE.PHD8V%C:&5?;F%M92`N/2`B7#`B
M('@@*"1C86-H95]N86UE7W-I>F4@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD
M9F@M/G!R:6YT*"1C86-H95]N86UE+`HB7#!#04-(12(I.PI]"FUY("1O9F9S
M970@/2`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BD["B1F:"T^<')I;G0H
M<&%C:R@G3B<L("1O9F9S970I+`HD4$%27TU!1TE#*3L*)&9H+3YC;&]S92!O
M<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T<F%I;&5R(&]F("(D;W5T(CH@)"%=
M.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F
M:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2
M.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&
M:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!!
M<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D
M;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N*"D@9F%I
M;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D[
M"FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"1Z:7`M/G)E861&<F]M
M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B
M)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@
M,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A
M8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO=71S*")%>'1R86-T:6YG('II<"XN
M+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B
M92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II
M<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*
M;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL
M97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z
M.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C
M=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F
M:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D
M97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE
M*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I
M="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*
M;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N
M86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T
M7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R
M<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T;R`B)&1E<W1?;F%M92)=.PIC
M:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*
M?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@
M/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@
M6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN
M<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[
M4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I
M.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@
M/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D[
M"G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H
M*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*
M?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@
M1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*
M<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`[
M"G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@
M17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C
M;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*
M<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z
M.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ
M6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI3
M2$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@
M4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q
M=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I
M8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7
M:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![
M(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U
M:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E
M(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q
M=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO
M*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T
M:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U0
M1$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE
M>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D
M<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I
M(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D
M*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,
M;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M
M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-
M17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0IM>2`D<W1M<&1I<B`]
M("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA
M;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;7D@)&-A8VAE7V1I<CL*:68@
M*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PI]
M"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I
M92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["FEF("@H;7D@)&UA
M9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F:"DI(#X](#`I('L*<V5E:R`D
M9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B
M7#!#04-(12(I+"`P.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@;&5N9W1H
M*")<,$-!0TA%(BD["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F
M:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<
M,$-!0TA%(BD*+2`D8V%C:&5?;F%M95]S:7IE+"`P.PIR96%D("1F:"P@)&)U
M9BP@)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]?B!S+UPP+R]G.PHD8V%C:&5?
M9&ER(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO<V4@)&9H.PI]"FEF("@A)&-A
M8VAE7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PHD14Y6>U!!4E]#
M3$5!3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D<WES>U]D96QI;7TD8V%C:&5?
M9&ER(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["B1%3E9[4$%27U1%35!](#T@
M)'-T;7!D:7(["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?
M5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W-A
M=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY
M("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F
M=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;7D@
M)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T96UP;F%M92D*)B8@*'!R:6YT
M("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D9F@I"F]R(&1I92!Q<5M%<G)O
M<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T["F-H;6]D("1M;V1E+"`D=&5M
M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U
M;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN
M86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM0
M05)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO
M*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D
M14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]4
M14U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R
M:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI("L@,2D["GT*:68@*"$D
M14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D<WES>U]D
M96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M
M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)'-Y
M<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S>7-[7V5X97T["G)E='5R;CL*
M?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H7W-E<'U<
M12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-
M4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421S
M>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L
M:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1S
M>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB.PHH*"1P<F]G;F%M92`]
M("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D
M9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N
M86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*
M:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I('L*)'!R
M;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@
M/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H
M9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@
M<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<
M421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.5GM005)?
M4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*
M:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX[
M"GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ
M=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@
M*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*?0IF;W(@*'%W+R!435!$25(@
M5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[(E!!4E\D7R)](#T@)$5.5GLB
M4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6>R)005)?1TQ/0D%,7R1?
M(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#
M3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D
M;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@
M(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U
M<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1?
M?2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E
M;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G
M92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN
M9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP87(N<&PZ
M($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@
M9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M93L*9&\@
M)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E4
M7UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D
M0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>
M7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?
M15)23U(["C$["E]?14Y$7U\*`````````````$-!0TA%``!P97)L>'-I+F,`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MJ!X````````X'@`````````````````````````````*4$%2+G!M"@``````
M````6&<`````````````````````````````````````````````````````
M``````"`L!H```````````(``````#@``@``````$`,"````````````````
M`````0``````>#\```````"H)P```````)@S````````R"@```````!8-@``
M`````!@M````````P#<```````#8*P```````&!?````````(``"``````!0
M0@`````````````````````````````@8P```````!!C`````````&,`````
M``#P8@```````.!B````````T&(``````````````````,!B````````L&(`
M``````"@8@```````)!B````````@&(```````!P8@```````&!B````````
M4&(```````!`8@```````#!B````````(&(````````08@````````!B````
M````\&$```````#@80```````-!A````````P&$``````````````````+!A
M``````````````````"@80```````)!A````````@&$```````!P80``````
M`&!A`````````````````````````````%!A````````0&$````````P80``
M```````````````````````````@80```````!!A`````````&$```````#P
M8```````````````````X&````````#08````````,!@````````````````
M``"P8````````*!@````````D&````````"`8````````'!@````````8&``
M``````!08````````$!@````````,&`````````@8```````````````````
M```````````08`````````!@````````\%\```````#@7P```````-!?````
M````P%\```````"P7P```````*!?```````````````````0`P(``````$=#
M0SH@*$1E8FEA;B`Q,RXR+C`M,3@I(#$S+C(N,```T!X`````?Y#X____````
M``````!0````'0```!\```!((``````#D/C___\````````````!```=````
M'P```/@@`````!^0^/___P``````````(`$``!T````?````Z"(`````_Y#X
M____``````````!@````'0```!\```"0)0`````?D/C___\``````````%`0
M```=````'P```,@F``````&0^/___P``````````(````!T````?````4"<`
M`````)#X____```````````0````'0```!\```"H)P`````/D/C___\`````
M`````%`@```=````'P```+`H`````````````````````````````!T````?
M````R"@`````_]#X____``````````!0$0``'0```!\```"`*P`````!D/C_
M__\``````````"`````=````'P```-@K``````^0^/___P``````````0!``
M`!T````?````&"T`````_]#X____``````````!P````'0```!\`````,P``
M```!D/C___\``````````#`````=````'P```)@S``````"0N/___P``````
M````8````!T````?````$#0`````/Y#X____``````````!0``$`'0```!\`
M```0-@``````D/C___\``````````!`````=````'P```%@V`````!^0^/__
M_P``````````4````!T````?````P#<`````_]#X____`````````````@``
M'0```!\```!X/P`````_D/C___\``````````%`````=````'P```%!"````
M``>0^/___P``````````0````!T````?````L!H`````/Y#X____````````
M``!P````'0```!\```"00P`````'D/C___\``````````,`"```=````'P``
M`$!:``````"0^/___P``````````$````!T````?````R%H`````?Y#X____
M``````````!0````'0```!\```"X7``````_D/C___\``````````$`````=
M````'P```&!?``````"0^/___P``````````$````!T````?````00\```!G
M;G4``0<````$`0`N<VAS=')T86(`+FEN=&5R<``N34E04RYA8FEF;&%G<P`N
M34E04RYO<'1I;VYS`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G
M`"YD>6YA;6EC`"YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`
M+F=N=2YV97)S:6]N7W(`+G)E;"YD>6X`+FEN:70`+G1E>'0`+DU)4%,N<W1U
M8G,`+F9I;FD`+G)O9&%T80`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?
M87)R87D`+F1A=&$`+G)L9%]M87``+F=O=``N<V1A=&$`+F)S<P`N8V]M;65N
M=``N<&1R`"YG;G4N871T<FEB=71E<P``````````````````````````````
M````````````````````````````````````````````````````````````
M```+`````0````(`````````<`(```````!P`@````````\`````````````
M```````!````````````````````$P```"H``'`"`````````(`"````````
M@`(````````8````````````````````"``````````8`````````"(````-
M``!P`@``"`````"8`@```````)@"````````D`$```````````````````@`
M`````````0`````````P````!P````(`````````*`0````````H!```````
M`"0````````````````````$````````````````````0P````<````"````
M`````$P$````````3`0````````@````````````````````!```````````
M`````````%$````&`````@````````!P!````````'`$````````8`(`````
M```)``````````@`````````$`````````!:````!0````(`````````T`8`
M``````#0!@```````"P#````````"``````````(``````````0`````````
M8`````L````"```````````*``````````H```````#`"0````````D````"
M````"``````````8`````````&@````#`````@````````#`$P```````,`3
M````````T00```````````````````$```````````````````!P````____
M;P(`````````DA@```````"2&````````-``````````"``````````"````
M``````(`````````?0```/[__V\"`````````&@9````````:!D```````"@
M``````````D````"````"````````````````````(P````)`````@``````
M```(&@````````@:````````8``````````(``````````@`````````$```
M``````"5`````0````8`````````:!H```````!H&@```````$``````````
M```````````$````````````````````FP````$````&`````````+`:````
M````L!H```````#P1```````````````````$````````````````````*$`
M```!````!@````````"@7P```````*!?````````H`,`````````````````
M``@```````````````````"M`````0````8`````````0&,```````!`8P``
M`````"@````````````````````$````````````````````LP````$````"
M`````````'!C````````<&,```````"`00``````````````````$```````
M`````````````+L````!`````@````````#PI````````/"D````````!```
M``````````````````0```````````````````#%````#@````,`````````
M\/\!``````#P_P````````@````````````````````(``````````@`````
M````T0````\````#`````````/C_`0``````^/\````````(````````````
M````````"``````````(`````````-T````!`````P````````````(`````
M`````0``````,````````````````````!````````````````````#C````
M`0````,`````````,``"```````P``$```````@````````````````````(
M````````````````````[`````$````#```0`````$```@``````0``!````
M``#0`@``````````````````$``````````(`````````/$````!`````P``
M$``````0`P(``````!`#`0``````"`````````````````````@`````````
M``````````#X````"`````,`````````(`,"```````8`P$``````#``````
M```````````````0````````````````````_0````$````P````````````
M````````&`,!```````?`````````````````````0`````````!````````
M``8!```!`````````````````````````#@#`0``````8`,`````````````
M``````0````````````````````+`0``]?__;P````````````````````"8
M!@$``````!`````````````````````!`````````````````````0````,`
M````````````````````````J`8!```````;`0```````````````````0``
-````````````````````
